@@ -23,10 +23,7 @@
 #include "second-exec-core.h"
 #include "string-util.h"
 #include "utils.h"
-
-extern "C" {
 #include "lomiri-app-launch-trace.h"
-}
 
 #include <gio/gio.h>
 #include <sys/types.h>
@@ -97,7 +94,11 @@ std::vector<pid_t> SystemD::pids()
 void SystemD::stop()
 {
     auto manager = std::dynamic_pointer_cast<manager::SystemD>(registry_->jobs());
-    manager->stopUnit(appId_, job_, instance_);
+    try {
+        manager->stopUnit(appId_, job_, instance_);
+    } catch (const std::runtime_error& e) {
+        g_warning("Error occured while stopping unit: %s", e.what());
+    }
 }
 
 }  // namespace instance
@@ -448,9 +449,10 @@ std::vector<std::string> SystemD::parseExec(std::list<std::pair<std::string, std
     auto appexecpolicy = findEnv("APP_EXEC_POLICY", env);
     if (!appexecpolicy.empty() && appexecpolicy != "unconfined")
     {
+        retval.emplace(retval.begin(), "--");
         retval.emplace(retval.begin(), appexecpolicy);
         retval.emplace(retval.begin(), "-p");
-        retval.emplace(retval.begin(), "aa-exec");
+        retval.emplace(retval.begin(), AA_EXEC_PATH);
     }
 
     return retval;
@@ -467,7 +469,7 @@ void SystemD::application_start_cb(GObject* obj, GAsyncResult* res, gpointer use
 {
     auto data = static_cast<StartCHelper*>(user_data);
 
-    tracepoint(lomiri_app_launch, libual_start_message_callback, std::string(data->ptr->appId_).c_str());
+    tracepoint(lomiri_app_launch, liblal_start_message_callback, std::string(data->ptr->appId_).c_str());
 
     g_debug("Started Message Callback: %s", std::string(data->ptr->appId_).c_str());
 
@@ -563,7 +565,7 @@ std::shared_ptr<Application::Instance> SystemD::launch(
         std::string appIdStr{appId};
         g_debug("Initializing params for an new instance::SystemD for: %s", appIdStr.c_str());
 
-        tracepoint(lomiri_app_launch, libual_start, appIdStr.c_str());
+        tracepoint(lomiri_app_launch, liblal_start, appIdStr.c_str());
 
         int timeout = 1;
         if (lomiri::app_launch::Registry::Impl::isWatchingAppStarting())
@@ -589,6 +591,7 @@ std::shared_ptr<Application::Instance> SystemD::launch(
         auto env = getenv();
 
         env.emplace_back(std::make_pair("APP_ID", appIdStr));                           /* Application ID */
+        env.emplace_back(std::make_pair("DESKTOP_FILE_HINT", appIdStr));                /* Application ID for .desktop matching */
         env.emplace_back(std::make_pair("APP_LAUNCHER_PID", std::to_string(getpid()))); /* Who we are, for bugs */
 
         copyEnv("DISPLAY", env);
@@ -709,7 +712,7 @@ std::shared_ptr<Application::Instance> SystemD::launch(
         g_variant_builder_open(&builder, G_VARIANT_TYPE_TUPLE);
         g_variant_builder_add_value(&builder, g_variant_new_string("Type"));
         g_variant_builder_open(&builder, G_VARIANT_TYPE_VARIANT);
-        g_variant_builder_add_value(&builder, g_variant_new_string("oneshot"));
+        g_variant_builder_add_value(&builder, g_variant_new_string("simple"));
         g_variant_builder_close(&builder);
         g_variant_builder_close(&builder);
 
@@ -785,7 +788,7 @@ std::shared_ptr<Application::Instance> SystemD::launch(
                                chelper                             /* object */
                                );
 
-        tracepoint(lomiri_app_launch, libual_start_message_sent, appIdStr.c_str());
+        tracepoint(lomiri_app_launch, liblal_start_message_sent, appIdStr.c_str());
 
         return retval;
     });
